cosinnus.models.serializers package
===================================

Submodules
----------

cosinnus.models.serializers.base module
---------------------------------------

.. automodule:: cosinnus.models.serializers.base
    :members:
    :undoc-members:
    :show-inheritance:

cosinnus.models.serializers.group module
----------------------------------------

.. automodule:: cosinnus.models.serializers.group
    :members:
    :undoc-members:
    :show-inheritance:

cosinnus.models.serializers.profile module
------------------------------------------

.. automodule:: cosinnus.models.serializers.profile
    :members:
    :undoc-members:
    :show-inheritance:

cosinnus.models.serializers.tagged module
-----------------------------------------

.. automodule:: cosinnus.models.serializers.tagged
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: cosinnus.models.serializers
    :members:
    :undoc-members:
    :show-inheritance:
